@@ -1,4 +1,5 @@
 from miamcpdoc.main import create_server
+from miamcpdoc.splash import SPLASH
 
 def main():
     """LangGraph and LangChain Documentation MCP Server."""
@@ -7,6 +8,8 @@ def main():
         {"name": "LangChain", "llms_txt": "https://python.langchain.com/llms.txt"}
     ]
     
+    print(SPLASH)
+    print("Loading LangGraph and LangChain documentation...")
     server = create_server(doc_sources)
     server.run(transport="stdio")
 
